diff --git a/Core/Inc/sys_conf.h b/Core/Inc/sys_conf.h
index 4941614..f10502a 100644
--- a/Core/Inc/sys_conf.h
+++ b/Core/Inc/sys_conf.h
@@ -47,12 +47,12 @@ extern "C" {
/**
* @brief Verbose level for all trace logs
*/
-#define VERBOSE_LEVEL VLEVEL_OFF
+#define VERBOSE_LEVEL VLEVEL_M
/**
* @brief Enable trace logs
*/
-#define APP_LOG_ENABLED 0
+#define APP_LOG_ENABLED 1
/**
* @brief Activate monitoring (probes) of some internal RF signals for debug purpose
@@ -75,13 +75,13 @@ extern "C" {
* @brief Enable/Disable MCU Debugger pins (dbg serial wires)
* @note by HW serial wires are ON by default, need to put them OFF to save power
*/
-#define DEBUGGER_ENABLED 0
+#define DEBUGGER_ENABLED 1
/**
* @brief Disable Low Power mode
* @note 0: LowPowerMode enabled. MCU enters stop2 mode, 1: LowPowerMode disabled. MCU enters sleep mode only
*/
-#define LOW_POWER_DISABLE 0
+#define LOW_POWER_DISABLE 1
/* USER CODE BEGIN EC */
diff --git a/Core/Inc/yunhorn_sts_prd_conf.h b/Core/Inc/yunhorn_sts_prd_conf.h
index a039b63..8f574b5 100644
--- a/Core/Inc/yunhorn_sts_prd_conf.h
+++ b/Core/Inc/yunhorn_sts_prd_conf.h
@@ -112,7 +112,7 @@
#define YUNHORN_STS_AC_CODE_SIZE 20U
#define STS_NVM_CFG_SIZE 32U
-#define STS_CFG_PCFG_SIZE 28U
+#define STS_CFG_PCFG_SIZE 20U
#define STS_CFG_CMD_SIZE 30U
#define STS_CFG_CMD_SHORT_LEN 8U
#define STS_MODE_COLOR_CMD_LEN 5U
diff --git a/Core/Inc/yunhorn_sts_sensors.h b/Core/Inc/yunhorn_sts_sensors.h
index a80a3a2..a977120 100644
--- a/Core/Inc/yunhorn_sts_sensors.h
+++ b/Core/Inc/yunhorn_sts_sensors.h
@@ -485,29 +485,55 @@ typedef struct
// 0 --- 10 11 12 -- 39 40 41 42 43 44-63
// LEN P RSS FALL_DETECTION AC_CODE
enum nvm_order {
- NVM_MTM1=0,
- NVM_MTM2,
- NVM_VER,
- NVM_HWV,
- NVM_PERIODICITY,
- NVM_UNIT,
- NVM_SAMPLING,
- NVM_S_UNIT,
- NVM_WORK_MODE,
- NVM_SERVICE_MASK,
- NVM_RESERVE01, //10
+ NVM_MTM1=0, // 0
+ NVM_MTM2, // 1
+ NVM_VER, // 2
+ NVM_HWV, // 3
+ NVM_PERIODICITY, // 4
+ NVM_UNIT, // 5
+ NVM_SAMPLING, // 6
+ NVM_S_UNIT, // 7
+ NVM_WORK_MODE, // 8
+ NVM_SERVICE_MASK, // 9
+ NVM_IOC_MASK, //10
NVM_LEN, //11, 32=0x20
- NVM_CFG_START, //12, p[0] bytes for configs,
+ NVM_CFG_START=12, //12, p[0] bytes for configs,
//13, p[1]
//14, p[2]
- // ...
- //39, P[27]
- NVM_FALL_DETECTION_ACC_THRESHOLD=40, //40
- NVM_FALL_DETECTION_DEPTH_THRESHOLD, //41
- NVM_FALL_DETECTION_RESERVE, //42
- NVM_OCCUPANCY_OVERTIME_THRESHOLD, //43
- NVM_AC_CODE_START=44 //STORED, NO UPLOAD
- //63, 20 bytes for AC code
+ //15, p[3]
+ //16, p[4]
+ //17, p[5]
+ //18, p[6]
+ //19, p[7]
+ //20, p[8]
+ //21, p[9]
+ //22, p[10]
+ //23, p[11]
+ //24, p[12]
+ //25, p[13]
+ //26, p[14]
+ //27, p[15]
+ //28, p[16]
+ //29, p[17]
+ //30, p[18]
+ NVM_CFG_START_END=31, //31, p[19]
+ NVM_RESERVE02, //32
+ NVM_RESERVE03, //33
+ NVM_SENSOR_INSTALL_HEIGHT, //34
+ NVM_ALARM_PARAMETER05, //35
+ NVM_ALARM_MUTE_RESET_TIMER, //36
+ NVM_ALARM_LAMP_BAR_FLASHING_COLOR, //37
+ NVM_OCCUPANCY_OVERTIME_THRESHOLD, //38
+
+ NVM_MOTIONLESS_DURATION_THRESHOLD, //39
+ NVM_UNCONSCIOUS_LEVEL_THRESHOLD, //40
+
+ NVM_FALL_DETECTION_ACC_THRESHOLD, //41
+ NVM_FALL_DETECTION_DEPTH_THRESHOLD, //42
+ NVM_FALL_CONFIRM_THRESHOLD, //43
+
+ NVM_AC_CODE_START=44 //STORED, NO UPLOAD
+ //63, 20 bytes for AC code
};
typedef struct sts_cfg_nvm {
@@ -524,10 +550,22 @@ typedef struct sts_cfg_nvm {
uint8_t reseve01;
uint8_t length; // length of following parameters except AC CODE(20bytes)
uint8_t p[STS_CFG_PCFG_SIZE];
- uint8_t fall_detection_acc_threshold; // 0 - 9: 0:disable: 1-9 accelaration mg/s2
+
+ uint8_t reserve02;
+ uint8_t reserve03;
+ uint8_t sensor_install_height_in_10cm;
+ uint8_t alarm_parameter05;
+ uint8_t alarm_mute_reset_timer_in_10sec; //60(0x3C) sec alarm_mute_or_reset_expire_timer_in_sec
+ uint8_t alarm_lamp_bar_flashing_color; //Lamp Bar Flashing color define, 0x20, 2==STS_RED, 0 = STS_DARK, 0x23, 2=STS_RED, 3=STS_BLUE
+ uint8_t occupancy_overtime_threshold_in_10min; // 0 - 9: 0:disable, 1-9 occupy over time threshold * 10 min
+
+ uint8_t motionless_duration_threshold_in_min; // 10(0x0A) min (2 min.) motionless_duration_threshold_in_min
+ uint8_t unconscious_or_motionless_level_threshold; // 0 - 9 motion level *128
+
+ uint8_t fall_detection_acc_threshold; // 0 - 9: 0:disable: 1-9 accelaration mg/s2
uint8_t fall_detection_depth_threshold; // 0 - 9: 0:disable: 1-9 fall down depth * 10 cm
- uint8_t fall_detection_reserve;
- uint8_t occupancy_overtime_threshold; // 0 - 9: 0:disable, 1-9 occupy over time threshold * 10 min
+ uint8_t fall_confirm_threshold_in_10sec; // 0-60(0x3C) Sec, or 3*10(0x03) sec default falldown_confirm_threshold_in_10sec
+
uint8_t ac[YUNHORN_STS_AC_CODE_SIZE]; // authorization code, 20 bytes MCU UUID coded
} sts_cfg_nvm_t;
diff --git a/Core/Src/dma.c b/Core/Src/dma.c
index b2e80c9..343b6b8 100644
--- a/Core/Src/dma.c
+++ b/Core/Src/dma.c
@@ -77,7 +77,7 @@ void MX_DMA_Init(void)
HAL_NVIC_SetPriority(DMA1_Channel6_IRQn, 0, 0);
HAL_NVIC_EnableIRQ(DMA1_Channel6_IRQn);
#endif
-#if 0
+#if 1
/* DMA1_Channel7_IRQn interrupt configuration */
HAL_NVIC_SetPriority(DMA1_Channel7_IRQn, 2, 0);
HAL_NVIC_EnableIRQ(DMA1_Channel7_IRQn);
diff --git a/LoRaWAN/App/lora_app.h b/LoRaWAN/App/lora_app.h
index a5530fe..0583c61 100644
--- a/LoRaWAN/App/lora_app.h
+++ b/LoRaWAN/App/lora_app.h
@@ -71,7 +71,7 @@ extern "C" {
/*!
* LoRaWAN default class
*/
-#define LORAWAN_DEFAULT_CLASS CLASS_A
+#define LORAWAN_DEFAULT_CLASS CLASS_C
/*!
* LoRaWAN default confirm state
diff --git a/STM32CubeIDE/.settings/language.settings.xml b/STM32CubeIDE/.settings/language.settings.xml
index 3ab6a6d..0ec3934 100644
--- a/STM32CubeIDE/.settings/language.settings.xml
+++ b/STM32CubeIDE/.settings/language.settings.xml
@@ -5,7 +5,7 @@
-
+
@@ -16,7 +16,7 @@
-
+
diff --git a/readme.txt b/readme.txt
index 10b5109..9c75cee 100644
--- a/readme.txt
+++ b/readme.txt
@@ -46,4 +46,5 @@ Pre-defines
2024-05-28 GOOD R1D with lower power and TPS shutdown to 0V, yet, TOF range data incorrect. or not ranging at all
2024-05-28 range distance same 1000mm
2024-07-03 GPIO analog cannot be RESET in enterStopMode...only deinit
+ 2024-08-29 STS-P2-L1X start
******************************************************************************
diff --git a/LoRaWAN/App/lora_app.c b/LoRaWAN/App/lora_app.c
index 8126aab..541d917 100644
--- a/LoRaWAN/App/lora_app.c
+++ b/LoRaWAN/App/lora_app.c
@@ -68,19 +68,19 @@ volatile sts_cfg_nvm_t sts_cfg_nvm = {
sts_mtmcode2,
sts_version,
sts_hardware_ver,
- 0x01, //Regular TxPeriodicity interval
- 'M', //unit of Regular TxPeriodicity interval
- 0x3C, //Heart-beat interval or Sampling interval
- 'M', //unit of Heart-beat interval or Sampling interval
- 0x04, // dual mode
- 0x00, // service mask
- 0x00, // reserve01
- 0x20, //32 bytes, below start of p[0]
- { // *******************below 28 bytes
- 0x08, //start_m [8]*0.1 meter =0.8
- 0x19, //lenght_m 0x19=[25]*0.1=2.5f meter
- 0x0F, //threshold 0X0F=[15]*0.1=1.5f
- 0x28, //receiver gain 0x28 =[40]*0.01=0.40f max 99=0x63
+ 0x01, //Regular TxPeriodicity interval
+ 'M', //Uplink data interval unit, for heart-beat uplink
+ 0x3C, //Heart-beat interval or Sampling interval
+ 'M', //Sampling sensor interval unit, for real-time sensing of MEMS
+ 0x04, // dual mode=4, uni_mode =5
+ 0x00, // sts service mask
+ 0x00, //sts_ioc_mask
+ 0x20, //32 bytes, below start of p[0] 20 BYTES AND 12 BYTES FALL DOWN CFG
+ { // below 20 bytes
+ 0x08, //start_m [8]*0.1 meter =0.8
+ 0x19, //lenght_m 0x19=[25]*0.1=2.5f meter
+ 0x0F, //threshold 0X0F=[15]*0.1=1.5f
+ 0x28, //receiver gain 0x28 =[40]*0.01=0.40f max 99=0x63
0x04, //profile [4]=4
0x0A, //rate tracking 0x0A=10= 10U
0x41, //rate presence 0x41=65= 65U
@@ -89,32 +89,32 @@ volatile sts_cfg_nvm_t sts_cfg_nvm = {
0x05, //inter frame deviation time const 0x05=[5]*0.1=0.5f
0x0A, //inter frame fast cutoff 0x0A=[10] = 10U
0x01, //inter frame slow cutoff,0x01=1[1]*0.01=0.01f
- 0x00, //intra frame time const [0]=0
- 0x00, //intra frame weight, 0x00=[0]*0.1=0.0F
+ 0x00, ///intra frame time const [0]=0 Lower to reduce sensitivity, higher to increase sensitivity
+ 0x0A, //intra frame weight, 0x00=[0]*0.1=0.0F 0x0A=10, 10*0.1=1 FOR FAST MOVEMENT TRACKING FALL DETECTION
0x05, //output time const 0x05=[5]*0.1=0.5
0x02, //downsampling factor [2]=2
0x03, //power saving mode ACTIVE [3] = 3U
- 0xFF, //reserve
- 0xFF, //reserve
- 0xFF, //reserve
- 0xFF, //reserve
- 0xFF, //reserve
- 0xFF, //reserve
- 0xFF, //reserve
- 0xFF, //reserve
- 0xFF, //reserve
- 0xFF, //reserve
- 0xF, //reserve
- }, // ******************* above 28 bytes28 bytes
- // ******************* below 4 bytes
+ 0x00, //reserve --P[17]
+ 0x00, //reserve --P[18]
+ 0x00, //reserve --P[19]
+ }, // above 20 bytes
+ 0x00, //reserve2
+ 0x00, //reserve3
+ 0x20, //sensor install height in 10 cm, default 32*10=320cm, 3.2meter
+
+ 0x00, //reserve5 alarm_parameter05
+ 0x06, //reserve6 alarm_mute_or_reset_expire_timer_in_10sec, 60 seconds
+ 0x23, //reserve7 alarm Lamp Bar Flashing color define, 0x20, 2==STS_RED, 0 = STS_DARK, 0x23, 2=STS_RED, 3=STS_BLUE
+ 0x03, //reserve8 occupancy over time threshold 3*10 = 30 minutes
+
+ 0x09, //reserve8 motionless_duration_threshold_in_min+1, normal: 10 min(0x0A) Minutes (2 min.) 1-9== 2-10min
+ 0x09, //unconscious threshold * 128, 0-9, 9*128=1280 motion level
+
0x01, //fall_detection_acc_threshold = *10 acceleration measure
0x03, //fall detection_depth_threshold *10cm
- 0x00, //reserve
- 0x02, //occupancy over time threshold *10 minutes
- // ******************* ABOVE 4 bytes
- // below 20 bytes AC
- {0x0,0x0,0x0,0x0,0x0, 0x0,0x0,0x0,0x0,0x0, 0x0,0x0,0x0,0x0,0x0, 0x0,0x0,0x0,0x0,0x0}
-
+ 0x03, //falldown_confirm_threshold_in_10sec, 0x3=30 sec default
+ // below 20 bytes for RFAC code
+ {0x0,0x0,0x0,0x0,0x0, 0x0,0x0,0x0,0x0,0x0, 0x0,0x0,0x0,0x0,0x0, 0x0,0x0,0x0,0x0,0x0},
};
@@ -1582,7 +1582,7 @@ void USER_APP_AUTO_RESPONDER_Parse(char *tlv_buf, size_t tlv_buf_size)
outbuf[i++] = (uint8_t) cfg_in_nvm[NVM_S_UNIT]; //Heart-beat or SAMPLING Periodicity unit
outbuf[i++] = (uint8_t) cfg_in_nvm[NVM_WORK_MODE]; // STS WORK MODE
outbuf[i++] = (uint8_t) cfg_in_nvm[NVM_SERVICE_MASK]; //service mask
- outbuf[i++] = (uint8_t) cfg_in_nvm[NVM_RESERVE01]; //service mask
+ outbuf[i++] = (uint8_t) cfg_in_nvm[NVM_IOC_MASK]; //service mask
outbuf[i++] = (uint8_t) cfg_in_nvm[NVM_LEN]; //length of following cfg value
for (uint8_t j=0; j < cfg_in_nvm[NVM_LEN]; j++) {
@@ -1945,8 +1945,8 @@ void OnStoreSTSCFGContextRequest(void)
nvm_store_value[i++] = sts_cfg_nvm.fall_detection_acc_threshold;
nvm_store_value[i++] = sts_cfg_nvm.fall_detection_depth_threshold;
- nvm_store_value[i++] = sts_cfg_nvm.fall_detection_reserve;
- nvm_store_value[i++] = sts_cfg_nvm.occupancy_overtime_threshold;
+ nvm_store_value[i++] = sts_cfg_nvm.fall_confirm_threshold_in_10sec;
+ //nvm_store_value[i++] = sts_cfg_nvm.occupancy_overtime_threshold;
if ((sts_cfg_nvm.ac[0]!=0x0) && (sts_cfg_nvm.ac[19]!=0x0)) {
for (j = 0; j < YUNHORN_STS_AC_CODE_SIZE; j++) {
nvm_store_value[i++] = (sts_cfg_nvm.ac[j]);
@@ -2008,7 +2008,7 @@ void STS_REBOOT_CONFIG_Init(void)
sts_cfg_nvm.s_unit = (uint8_t)(nvm_stored_value[NVM_S_UNIT]);
sts_cfg_nvm.work_mode = (uint8_t)(nvm_stored_value[NVM_WORK_MODE]);
sts_cfg_nvm.sts_service_mask = (uint8_t)(nvm_stored_value[NVM_SERVICE_MASK]);
- sts_cfg_nvm.reseve01 = (uint8_t)(nvm_stored_value[NVM_RESERVE01]);
+ sts_cfg_nvm.reseve01 = (uint8_t)(nvm_stored_value[NVM_IOC_MASK]);
sts_cfg_nvm.length = (uint8_t)(nvm_stored_value[NVM_LEN]&0x3F); //MAX 32 bytes
for (uint8_t j=0; j< sts_cfg_nvm.length; j++) {
@@ -2017,8 +2017,8 @@ void STS_REBOOT_CONFIG_Init(void)
sts_cfg_nvm.fall_detection_acc_threshold = (uint8_t)nvm_stored_value[NVM_FALL_DETECTION_ACC_THRESHOLD];
sts_cfg_nvm.fall_detection_depth_threshold = (uint8_t)nvm_stored_value[NVM_FALL_DETECTION_DEPTH_THRESHOLD];
- sts_cfg_nvm.fall_detection_reserve = (uint8_t)nvm_stored_value[NVM_FALL_DETECTION_RESERVE];
- sts_cfg_nvm.occupancy_overtime_threshold = (uint8_t)nvm_stored_value[NVM_OCCUPANCY_OVERTIME_THRESHOLD];
+ sts_cfg_nvm.fall_confirm_threshold_in_10sec = (uint8_t)nvm_stored_value[NVM_FALL_CONFIRM_THRESHOLD];
+ //sts_cfg_nvm.occupancy_overtime_threshold = (uint8_t)nvm_stored_value[NVM_OCCUPANCY_OVERTIME_THRESHOLD];
for (uint8_t j=0; j< YUNHORN_STS_AC_CODE_SIZE; j++) {
sts_cfg_nvm.ac[j] = (uint8_t)nvm_stored_value[NVM_AC_CODE_START +j];